@@ -49,7 +49,6 @@ unsigned char skip_plugins;
 pid_t jpilot_master_pid = -1;
 int *glob_date_label;
 GtkWidget *glob_dialog;
-GtkTooltips *glob_tooltips;
 gint glob_date_timer_tag;
 
 void output_to_pane(const char *str) { return; }
@@ -112,8 +111,7 @@ int main(int argc, char *argv[])
    /* enable internationalization(i18n) before printing any output */
 #if defined(ENABLE_NLS)
 #  ifdef HAVE_LOCALE_H
-      char *current_locale;
-      current_locale = setlocale(LC_ALL, "");
+      setlocale(LC_ALL, "");
 #  endif
    bindtextdomain(EPN, LOCALEDIR);
    textdomain(EPN);
