@@ -1,10 +1,8 @@
-/* $Id: libplugin.h,v 1.39 2011-04-06 12:43:45 rousseau Exp $ */
-
 /*******************************************************************************
  * libplugin.h
  * A module of J-Pilot http://jpilot.org
  *
- * Copyright (C) 1999-2002 by Judd Montgomery
+ * Copyright (C) 1999-2014 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,24 +121,24 @@ int get_next_unique_pc_id(unsigned int *next_unique_id);
 #define COPY_FLAG     6
 #define UNDELETE_FLAG 7
 
-#define CLIST_DEL_RED 0xCCCC
-#define CLIST_DEL_GREEN 0xCCCC
-#define CLIST_DEL_BLUE 0xCCCC
-#define CLIST_NEW_RED 55000
-#define CLIST_NEW_GREEN 55000
-#define CLIST_NEW_BLUE 65535
-#define CLIST_MOD_RED 55000
-#define CLIST_MOD_GREEN 65535
-#define CLIST_MOD_BLUE 65535
-#define CLIST_PRIVATE_RED 60000
-#define CLIST_PRIVATE_GREEN 55000
-#define CLIST_PRIVATE_BLUE 55000
-#define CLIST_OVERDUE_RED 0xD900
-#define CLIST_OVERDUE_GREEN 0x0000
-#define CLIST_OVERDUE_BLUE 0x0000
-#define CLIST_DUENOW_RED 4369 
-#define CLIST_DUENOW_GREEN 40863   
-#define CLIST_DUENOW_BLUE 35466
+#define LIST_DEL_RED 204
+#define LIST_DEL_GREEN 204
+#define LIST_DEL_BLUE 204
+#define LIST_NEW_RED 214
+#define LIST_NEW_GREEN 214
+#define LIST_NEW_BLUE 255
+#define LIST_MOD_RED 214
+#define LIST_MOD_GREEN 255
+#define LIST_MOD_BLUE 255
+#define LIST_PRIVATE_RED 234
+#define LIST_PRIVATE_GREEN 214
+#define LIST_PRIVATE_BLUE 214
+#define LIST_OVERDUE_RED 217
+#define LIST_OVERDUE_GREEN 0
+#define LIST_OVERDUE_BLUE 0
+#define LIST_DUENOW_RED 17
+#define LIST_DUENOW_GREEN 159
+#define LIST_DUENOW_BLUE 138
 
 #define DIALOG_SAID_1        454
 #define DIALOG_SAID_PRINT    454
