@@ -46,7 +46,7 @@
 #define WRITE_MAX_BUF 4096
 
 /******************************* Global vars **********************************/
-int pipe_to_parent;
+extern int pipe_to_parent;
 
 int glob_log_file_mask;
 int glob_log_stdout_mask;
