@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-extern GtkTooltips *glob_tooltips;
 
 #ifndef ENABLE_STOCK_BUTTONS
    /* old behavior */
@@ -33,17 +32,17 @@ extern GtkTooltips *glob_tooltips;
       char str[100]; \
       gtk_widget_add_accelerator(widget, "clicked", accel_group, shortcut_key, shortcut_mask, GTK_ACCEL_VISIBLE); \
       sprintf(str, "%s   %s", tooltip, shortcut_text); \
-      set_tooltip(show_tooltips, glob_tooltips, widget, str, NULL); \
+      set_tooltip(show_tooltips, widget, str, NULL); \
    } \
    else \
-      set_tooltip(show_tooltips, glob_tooltips, widget, tooltip, NULL);\
+      set_tooltip(show_tooltips,  widget, tooltip, NULL);\
    gtk_box_pack_start(GTK_BOX(hbox_temp), widget, TRUE, TRUE, 0);
 
 #else
 
 #  define CREATE_BUTTON(widget, text, stock, tooltip, shortcut_key, shortcut_mask, shortcut_text) \
-   widget = gtk_button_new_from_stock(GTK_STOCK_ ## stock); \
-   set_tooltip(show_tooltips, glob_tooltips, widget, tooltip, NULL); \
+   widget = gtk_button_new_with_label(text); \
+   set_tooltip(show_tooltips,  widget, tooltip); \
    gtk_box_pack_start(GTK_BOX(hbox_temp), widget, TRUE, TRUE, 0);
 
 #endif
